PTMCMCSampler package
=====================

Submodules
----------

PTMCMCSampler.PTMCMCSampler module
----------------------------------

.. automodule:: PTMCMCSampler.PTMCMCSampler
    :members:
    :undoc-members:
    :show-inheritance:

PTMCMCSampler.nompi4py module
-----------------------------

.. automodule:: PTMCMCSampler.nompi4py
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: PTMCMCSampler
    :members:
    :undoc-members:
    :show-inheritance:
